/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { buildQueryContext, QueryFormData } from '@superset-ui/core';

/**
 * buildQuery 函数用于创建一个 QueryContext 实例，并将其发送到图表数据端点.
 * 除了包含要使用的数据源信息外，它还指定了类型（如完整有效载荷[full payload]、样本[samples]、查询[query]）和格式（如 CSV 或 JSON）,
 * 以及是否从数据源强制刷新数据，而不是使用缓存的数据副本。
 *
 * 更重要的是，QueryContext 包含一个属性 `queries`，它是一个数组，其中包含QueryObjects 的数组。
 * 一个 QueryObject 可以指定列、度量和过滤器等。通常只需在 baseQueryObject 的基础上指定一个查询即可，
 * 但对于一些更高级的用例，可以在 QueryObject 中定义后处理操作，或者在 viz 需要多个不同结果集时定义多个查询。
 */
export default function buildQuery(formData: QueryFormData) {
  const { cols: groupby } = formData;
  return buildQueryContext(formData, baseQueryObject => [
    {
      ...baseQueryObject,
      groupby,
    },
  ]);
}
