/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t, ChartMetadata, ChartPlugin } from '@superset-ui/core';
import buildQuery from './buildQuery';
import controlPanel from './controlPanel';
import transformProps from './transformProps';
import thumbnail from '../images/thumbnail.png';

export default class SupersetPluginChartHelloWorld extends ChartPlugin {
  /**
   * 构造函数用于传递相关的元数据和回调，这些元数据和回调会在库和应用程序中使用的相应注册表中注册。
   * 每个属性的详细说明请参见相应的导入文件。
   *
   * 值得注意的是，“buildQuery ”是可选的，
   * 只有需要进行后处理操作（透视、滚动聚合、排序等）或提交多个查询的高级可视化才需要它。
   */
  constructor() {
    const metadata = new ChartMetadata({
      description: 'Superset Plugin Chart Hello World',
      name: t('Hello World'),
      thumbnail,
    });

    super({
      buildQuery,
      controlPanel,
      loadChart: () => import('../SupersetPluginChartHelloWorld'),
      metadata,
      transformProps,
    });
  }
}
